User Guide v1
=============

Documentation is split into four categories, also accessible from links in the
side-bar.

.. grid:: 2
    :gutter: 4

    .. grid-item-card:: :material-regular:`directions_walk;3em`

        .. toctree::
            :caption: Tutorials
            :maxdepth: 1

            tutorials/install
            tutorials/single-PV
            tutorials/device

        +++

        Tutorials for installation and typical usage. New users start here.

    .. grid-item-card:: :material-regular:`directions;3em`

        .. toctree::
            :caption: How-to Guides
            :maxdepth: 1

            how-to/pseudopositioner
            how-to/docker

        +++

        Practical step-by-step guides for the more experienced user.

    .. grid-item-card:: :material-regular:`info;3em`

        .. toctree::
            :caption: Explanations
            :maxdepth: 1

            explanations/relationship-to-epics
            explanations/area-detector
            explanations/status
            explanations/staging

        +++

        Explanations of how the library works and why it works that way.

    .. grid-item-card:: :material-regular:`menu_book;3em`

        .. toctree::
            :caption: Reference
            :maxdepth: 1

            reference/core
            reference/builtin-devices
            reference/signals
            reference/positioners
            reference/logging
            reference/release_notes
            ../genindex

        +++

        Technically detailed API documentation.

